@@ -103,13 +103,15 @@ macro_rules! peek {
         }
     }};
 
-    ($i:expr, $f:ident( $( $args:tt )* ) ) => {
+    ($i:expr, $f:ident( $( $args:tt )* ) ) => {{
+        use $crate::run;
         $crate::peek!($i, run!($f($($args)*)))
-    };
+    }};
 
-    ($i:expr, $f:ident) => {
+    ($i:expr, $f:ident) => {{
+        use $crate::run;
         $crate::peek!($i, run!($f))
-    };
+    }};
 }
 
 /// Converts a function indentifier into a macro call. Useful when writing your own macro combinator.
@@ -299,10 +301,10 @@ macro_rules! complete {
         $crate::combinators::complete($f!($i, $($args)*), $e)
     };
 
-    ($i:expr, $efn:expr, $f:ident) => {
+    ($i:expr, $efn:expr, $f:ident) => {{
         use $crate::run
         $crate::complete!($i, $efn, run!($f))
-    };
+    }};
 }
 
 /// Turns `Result::Fail` and `Result::Incomplete` into `Result::Abort`.
